API Reference
=============

.. currentmodule:: pysylph

.. toctree::
   :hidden:

   Sketch <sketch>
   Sketcher <sketcher>
   Database <database>
   Profiler <profiler>
   Results <results>


.. only:: html

    Sketch
    ------

    .. autosummary::
        :nosignatures:

        pysylph.Sketch
        pysylph.GenomeSketch
        pysylph.SampleSketch


    Sketcher
    --------

    .. autosummary::
        :nosignatures:

        pysylph.Sketcher


    Database
    --------

    .. autosummary::
        :nosignatures:

        pysylph.Database
        pysylph.DatabaseFile


    Profiler
    --------

    .. autosummary::
        :nosignatures:

        pysylph.Profiler


    Results
    -------

    .. autosummary::
        :nosignatures:

        pysylph.AniResult
        pysylph.ProfileResult
